# Code generated from the linkML model

This directory holds the output generated with [LinkML generators](https://linkml.io/linkml/generators/index.html)
from the model in `src/pid4cat_model/datamodel/schema/pid4cat_model.yaml`.
Generators transform a linkml schema into another datamodel such as SQL or RDF, or into other artefacts,
such as JSON-Schema, a visualisation, or markdown documentation.

In a future version of the template this directory will be empty except for the readme.
Thereby updating the template will never interfere with code that you generated from your model.
